@@ -1,4 +1,4 @@
 library(testthat,quietly=TRUE)
 library(growcurves,quietly=TRUE)
 
-test_package("growcurves")
\ No newline at end of file
+test_check("growcurves")
\ No newline at end of file
